# sciviso
[![codecov.io](https://codecov.io/github/ArianeMora/sciviso/coverage.svg?branch=master)](https://codecov.io/github/ArianeMora/sciviso?branch=master)
[![PyPI](https://img.shields.io/pypi/v/sciviso)](https://pypi.org/project/sciviso/)

## A wrapper to format all plots the same 

Sci-viso is a wrapper around matplotlib and seaborn. These are already great libraries, but as I needed to generate
figures for publication, I found that I had specific formats that I needed, and continually adding these in was
making my code clunky and repetative. I also wanted my charts within a publication to have the same "look and feel",
like palette, font, sizing etc. So I made sciviso so that my figures could come out of python "publication ready" and
asthetic.

I have only made wrappers for charts that I use (obvs) but keen for people to add others or make suggestions (feel free
to do that via github issues).

Others:
https://github.com/lukelbd/proplot
https://matplotlib.org/stable/index.html#contributing

## Check out the docs

[Link to docs](https://arianemora.github.io/sciviso/)
